==> rcppbugs_0.0.8.tar.gz: rcppbugs/src/distribution.types.h <==
// -*- mode: C++; c-indent-level: 2; c-basic-offset: 2; tab-width: 8 -*-
///////////////////////////////////////////////////////////////////////////
// Copyright (C) 2012  Whit Armstrong                                    //
//                                                                       //
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the GNU General Public License as published by  //
// the Free Software Foundation, either version 3 of the License, or     //
// (at your option) any later version.                                   //
//                                                                       //
// This program is distributed in the hope that it will be useful,       //
// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
// GNU General Public License for more details.                          //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program.  If not, see <http://www.gnu.org/licenses/>. //
///////////////////////////////////////////////////////////////////////////

#ifndef DISTRIBUTION_TYPES_H
#define DISTRIBUTION_TYPES_H

enum distT { /*deterministic*/ deterministicT, linearDeterministicT, logisticDeterministicT,
             /*continuous*/ normalDistT, uniformDistT, gammaDistT, betaDistT,
             /*discrete*/ bernoulliDistT, binomialDistT };

#endif // DISTRIBUTION_TYPES_H

==> rcppbugs_0.1.1.tar.gz: rcppbugs/src/distribution.types.h <==
// -*- mode: C++; c-indent-level: 2; c-basic-offset: 2; tab-width: 8 -*-
///////////////////////////////////////////////////////////////////////////
// Copyright (C) 2012  Whit Armstrong                                    //
//                                                                       //
// This program is free software: you can redistribute it and/or modify  //
// it under the terms of the GNU General Public License as published by  //
// the Free Software Foundation, either version 3 of the License, or     //
// (at your option) any later version.                                   //
//                                                                       //
// This program is distributed in the hope that it will be useful,       //
// but WITHOUT ANY WARRANTY; without even the implied warranty of        //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
// GNU General Public License for more details.                          //
//                                                                       //
// You should have received a copy of the GNU General Public License     //
// along with this program.  If not, see <http://www.gnu.org/licenses/>. //
///////////////////////////////////////////////////////////////////////////

#ifndef DISTRIBUTION_TYPES_H
#define DISTRIBUTION_TYPES_H

enum distT { /*deterministic*/ deterministicT, linearDeterministicT, linearGroupedDeterministicT, logisticDeterministicT,
             /*continuous*/ normalDistT, uniformDistT, gammaDistT, betaDistT,
             /*discrete*/ bernoulliDistT, binomialDistT };

#endif // DISTRIBUTION_TYPES_H
